<!--
SPDX-FileCopyrightText: © 2024 nosludge <https://github.com/nosludge>
SPDX-FileContributor: szymonmaszke <github@maszke.co>

SPDX-License-Identifier: Apache-2.0
-->

# cogeol

<!-- vale off -->
<p align="center">
    <em>Use cog: https://github.com/nedbat/cog and endoflife: https://endoflife.date/ to automate Python version management!
</p>

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cogeol?style=for-the-badge&label=release&labelColor=grey&color=blue)](https://pypi.org/project/cogeol)
![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fnosludge%2Fcogeol%2Fmain%2Fpyproject.toml&style=for-the-badge&label=python&labelColor=grey&color=blue)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue?style=for-the-badge)](https://opensource.org/licenses/Apache-2.0)
![Coverage Hardcoded](https://img.shields.io/badge/coverage-100%25-green?style=for-the-badge)
![OSSF-Scorecard Score](https://img.shields.io/ossf-scorecard/github.com/nosludge/cogeol?style=for-the-badge&label=OSSF)

<p align="center">
✨ <a href="#-features">Features</a>
🚀 <a href="#-quickstart">Quickstart</a>
📚  <a href="https://nosludge.github.io/cogeol">Documentation</a>
🤝 <a href="#-contribute">Contribute</a>
👍 <a href="https://github.com/nosludge/cogeol/blob/main/ADOPTERS.md">Adopters</a>
📜 <a href="#-legal">Legal</a>
</p>
<!-- vale on -->

---

## ✨ Features

__cogeol__ is a … allowing you to:

- __Feature 1__: Description of the feature
- __Feature 2__: Description of the feature
- __Feature 3__: Description of the feature
- __Feature 4__: Description of the feature
- __Feature 5__: Description of the feature

## 🚀 Quick start

### ⚙️ Installation

```sh
> pip install cogeol
```

### ✅ Usage

```python
import cogeol

...
```

### 💡 Examples

<details>
  <summary><b><big>Short</big></b> (click me)</summary>

Description of the example

```python
# Short example
```

</details>

<details>
  <summary><b><big>Common</big></b> (click me)</summary>

Description of the example

```python
# Common use case
```

</details>

<details>
  <summary><b><big>Advanced</big></b> (click me)</summary>

Description of the example

```python
# Something advanced and cool
```

</details>

## 🤝 Contribute

Your help is more than welcome! See the documentation below to get started:

- [Code of Conduct](CODE_OF_CONDUCT.md)
- [Contributing Guide](CONTRIBUTING.md)
- [Roadmap](ROADMAP.md)
- [Changelog](CHANGELOG.md)
- [Report security vulnerabilities](SECURITY.md)
- [Open an Issue](https://github.com/nosludge/cogeol/issues)

## 📜 Legal

- This project is licensed under the _Apache 2.0 License_ - see
  the [LICENSE](LICENSE.md) file for details.
- This project is copyrighted by _nosludge_ - see
  the [COPYRIGHT](https://github.com/nosludge/cogeol/blob/main/COPYRIGHT.txt)
  file for details.
